#!/bin/sh
#
if [ $# -ne 9 ] 
	then
	echo "Usage:"
	echo "./createdb.sh instance database user password db2admin db2adminpswd path1 path2 path3"
	echo "where instance is the instance in which you are creating your database"
	echo "where database is the name of the database to be populated"
	echo "where user is the DB2 server operating system user name"
	echo "where password is the password of the user"
	echo "where db2admin is the administrator user ID specified during your DB2 installation"
	echo "where db2adminpswd is the administrator user password"
	echo "where path1 is the drive and path for tablespace files for temporary data"
	echo "where path2 is another drive and path for tablespace files for temporary data"
	echo "where path3 is the drive and path for tablespace files for tables and indexes"
	exit 127;
fi

instance=$1
database=$2
user=$3
password=$4
db2admin=$5
db2adminpswd=$6
path1=$7
path2=$8
path3=$9
#
db2 -v DETACH 
db2 -v CONNECT RESET 
db2 -v ATTACH TO $instance USER $db2admin USING $db2adminpswd > createdb.log
db2 -v CREATE DATABASE $database USING CODESET UTF-8 TERRITORY US >> createdb.log
db2 -v CONNECT TO $database >> createdb.log
db2 -v DROP TABLESPACE userspace1 >> createdb.log
db2 -v update db cfg for $database using LOCKTIMEOUT 10 >> createdb.log
db2 -v CONNECT RESET >> createdb.log
db2 -v DETACH >> createdb.log
#
db2 -v connect to $database user $db2admin using $db2adminpswd >> createdb.log
#
# 4000 * 4K = 16M
# Increase the SIZE parameter per sizing analysis.
#
db2 -v CREATE bufferpool BUFF4K deferred SIZE 4000 PAGESIZE 4K >> createdb.log
#
# 2000 * 16K = 32M
# Increase the SIZE parameter per sizing analysis.
#
db2 -v CREATE bufferpool BUFF16K deferred SIZE 2000 PAGESIZE 16K >> createdb.log
#
# 600 * 32K = 20M
# Increase the SIZE parameter per sizing analysis.
db2 -v CREATE bufferpool BUFF32K deferred SIZE 600 PAGESIZE 32K >> createdb.log
#
db2 -v connect reset >> createdb.log
#
db2 -v connect to $database user $db2admin using $db2adminpswd >> createdb.log
#
# 4K temp tablespace
db2 -v CREATE TEMPORARY TABLESPACE TEMP4K PAGESIZE 4K MANAGED BY SYSTEM USING \(\'$path1\'\) BUFFERPOOL BUFF4K >> createdb.log
#
# 16K temp tablespace
db2 -v CREATE TEMPORARY TABLESPACE TEMP16K PAGESIZE 16K MANAGED BY SYSTEM USING \(\'$path2\'\) BUFFERPOOL BUFF16K >> createdb.log
#
db2 -v DROP  TABLESPACE TEMPSPACE1 >> createdb.log
db2 -v ALTER TABLESPACE SYSCATSPACE BUFFERPOOL BUFF4K >> createdb.log
#
# Minimize the size of the default bufferpool.
db2 -v ALTER BUFFERPOOL IBMDEFAULTBP SIZE 2 >> createdb.log
#
db2 -v connect reset >> createdb.log
db2 -v DETACH >> createdb.log
#
db2 -v connect to $database user $db2admin using $db2adminpswd >> createdb.log

# Tablespace to contain small tables
# 30000 * 4K = 120M
db2 -v CREATE REGULAR TABLESPACE TABLE4K PAGESIZE 4K MANAGED BY DATABASE USING \(FILE \'$path3/table4k.tbs\' 30000\) BUFFERPOOL BUFF4K >> createdb.log
#
# Tablespace to contain large tables
# 15000 * 16K = 240M
db2 -v CREATE REGULAR TABLESPACE TABLE16K PAGESIZE 16K MANAGED BY DATABASE USING \(FILE \'$path3/table16K.tbs\' 15000\) BUFFERPOOL BUFF16K >> createdb.log
#
# Tablespace to contain indexes
# 15000 * 4K = 60M
#
db2 -v CREATE REGULAR TABLESPACE INDEX4K	PAGESIZE 4K	MANAGED BY DATABASE USING \(FILE \'$path3/index4k.tbs\' 15000\)	BUFFERPOOL BUFF4K >> createdb.log
#
# Long tablespace to contain long fields
# 3000 * 32K = 96M
#
db2 -v CREATE LONG TABLESPACE TABLE32K PAGESIZE 32K MANAGED BY DATABASE USING \(FILE \'$path3/table32K.tbs\' 3000\) BUFFERPOOL BUFF32K >> createdb.log
db2 -v GRANT CONNECT, IMPLICIT_SCHEMA ON DATABASE TO USER $user >> createdb.log
#
# Grant tablespace use to the schema owner
db2 -v GRANT USE OF TABLESPACE TABLE4K TO USER $user >> createdb.log
db2 -v GRANT USE OF TABLESPACE TABLE16K TO USER $user >> createdb.log
db2 -v GRANT USE OF TABLESPACE TABLE32K TO USER $user >> createdb.log
db2 -v GRANT USE OF TABLESPACE INDEX4K TO USER $user >> createdb.log
#
db2 -v connect reset >> createdb.log
#
db2 -v connect to $database user $user using $password >> createdb.log 
#
db2 -tvf tables.sql >> createdb.log 
db2 -tvf foreign.sql >> createdb.log 
db2 -tvf indexes.sql>> createdb.log 
db2 -tvf data.sql>> createdb.log 
db2 -td@ -f reqdelproj_block.sql>> createdb.log 
db2 -td@ -f rqprojlock_delete.sql>> createdb.log 
db2 -td@ -f rqprojlock_insert.sql>> createdb.log 
db2 -td@ -f rqdrop_view.sql >> createdb.log 
db2 -td@ -f rqdrop_views.sql >> createdb.log 
db2 -td@ -f rqdelete_project.sql >> createdb.log 
db2 -tvf DB2SchemaUpgrade71.sql >> createdb.log 

# db2 -tvf grant.sql>> createdb.log 
#
db2 -v connect reset >> createdb.log 
#
echo "Database installation complete. Check createdb.log for messages and errors."
exit 0
#
